@@ -224,6 +224,18 @@ sub get_keyword {
 	return($result);
 }
 
+sub get_group_desc {
+	my ($group) = @_;
+	my ($block, $brief, $keyword);
+
+	$keyword = '@group ' . $group;
+
+	$block=get_comment_block("modulegroups", $keyword);
+	$brief=get_keyword($block, $keyword);
+
+	return $brief;
+}
+
 sub make_css {
 	print(OUTPUT <<END
 		<style type="text/css">
@@ -603,12 +615,10 @@ END
 		<h2>$g</h2>
 END
 		);
-		if($g eq "Unknown") {
-			print(OUTPUT <<END
-		<p>These modules don't include any information on which group they belong to. The most probable reason is that they haven't been ported to the 0.2.x kernel yet.</p>
-END
-			);
-		}
+
+		my $brief=get_group_desc($g);
+		print(OUTPUT html_render($brief));
+
 		print(OUTPUT <<END
 		<ul>
 END
@@ -641,7 +651,7 @@ mkdir("modules");
 
 open(XML, ">modulesref.xml") or die("Can't open modulesref.xml for writing");
 print(XML <<END
-<!DOCTYPE module-documentation PUBLIC "-//Tablix//DTD Module Reference 0.2.0//EN" "http://www.tablix.org/releases/dtd/modulesref2r0.dtd">
+<!DOCTYPE module-documentation PUBLIC "-//Tablix//DTD Module Reference 0.2.1//EN" "http://www.tablix.org/releases/dtd/modulesref2r0.dtd">
 <module-documentation>
 END
 );
