@@ -1,5 +1,5 @@
-/* TABLIX, PGA general timetable solver                              */
-/* Copyright (C) 2002-2005 Tomaz Solc                                      */
+/* TABLIX, PGA general timetable solver                                    */
+/* Copyright (C) 2002-2006 Tomaz Solc                                      */
 
 /* This program is free software; you can redistribute it and/or modify    */
 /* it under the terms of the GNU General Public License as published by    */
@@ -15,7 +15,7 @@
 /* along with this program; if not, write to the Free Software             */
 /* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA */
 
-/* $Id: consecutive.c,v 1.8 2006-02-01 20:30:04 avian Exp $ */
+/* $Id: consecutive.c,v 1.10 2006-04-22 19:24:43 avian Exp $ */
 
 /** @module
  *
@@ -31,7 +31,7 @@
  * another. This module uses updater functions, so the weight and mandatory
  * values are ignored.
  *
- * @ingroup School scheduling
+ * @ingroup School scheduling, Multiweek scheduling
  */
 
 /** @tuple-restriction consecutive
@@ -249,27 +249,11 @@ int getevent(char *restriction, char *cont, tupleinfo *tuple)
 
 /* This is the updater function. It makes sure that dependent event is 
  * scheduled one period later than the independent event. */
-void updater(int src, int dst, table *tab)
+int updater(int src, int dst, int typeid, int resid)
 {
-	int src_time;
+	assert(typeid==time);
 
-	src_time=tab->chr[time].gen[src];
-
-	/* This should always be true if we correctly set the time domain
-	 * for the first event in each group. */
-
-	/* It means that the independent event is not on the last period
-	 * of the day. */
-
-	assert(src_time%periods<(periods-1));
-
-	/* Double-check that we don't set resource ID out of bounds. */
-
-	assert(src_time+1<(periods*days));
-
-	/* Next event in the group is scheduled one period later. */
-
-	tab->chr[time].gen[dst]=src_time+1;
+	return(resid+1);
 }
 
 /* This is the precalculate function. It is called after all restriction
@@ -308,7 +292,7 @@ int module_precalc(moduleoption *opt)
 			/* We have to check if this event is already dependent.
 			 * If it is, we report an error. */
 
-			if(updater_check(tupleid)) {
+			if(updater_check(tupleid, time)) {
 				error(_("Event '%s' already depends on another"
 					" event"), dat_tuplemap[tupleid].name);
 				free(residlist);
@@ -320,7 +304,7 @@ int module_precalc(moduleoption *opt)
 			 * second event depends on the first. The third event
 			 * depends on the second and so on. */
 
-			updater_new(cur->tupleid[n-1], tupleid, updater);
+			updater_new(cur->tupleid[n-1], tupleid, time, updater);
 		}
 
 		/* Now we have to make sure that the first event in the group
@@ -332,7 +316,7 @@ int module_precalc(moduleoption *opt)
 
 		residnum=0;
 		for(n=0;n<days*periods;n++) {
-			if(n%periods<(periods-cur->tupleidnum)) {
+			if(n%periods<=(periods-cur->tupleidnum)) {
 				residlist[residnum]=n;
 				residnum++;
 			}
