@@ -15,7 +15,7 @@
 /* along with this program; if not, write to the Free Software             */
 /* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA */
 
-/* $Id: sameday.c,v 1.5 2006-01-06 12:02:18 avian Exp $ */
+/* $Id: sameday.c,v 1.6 2006-05-10 15:52:37 avian Exp $ */
 
 /** @module
  *
@@ -212,7 +212,7 @@ int resource_ignore_sameday(char *restriction, char *content, resource *res)
 	 * that use this resource. */
 	for(tupleid=0;tupleid<dat_tuplenum;tupleid++) {
 		if(dat_tuplemap[tupleid].resid[typeid]==resid) {
-			events[tupleid].group->max_perday=INT_MAX;
+			events[tupleid].group->max_perday=periods;
 		}
 	}
 
@@ -477,6 +477,8 @@ int module_precalc(moduleoption *opt)
 					n, dat_tuplemap[group[n].tupleid].name,
 					group[n].num);
 
+				/* Warning: Can overflow here if 
+				 * group[n].max_perday is large */
 				limit=days*group[n].max_perday;
 
 				if(group[n].num>limit) {
