@@ -15,7 +15,7 @@
 /* along with this program; if not, write to the Free Software             */
 /* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA */
 
-/* $Id: sametimeas.c,v 1.3 2006-01-28 13:05:14 avian Exp $ */
+/* $Id: sametimeas.c,v 1.4 2006-04-22 19:24:43 avian Exp $ */
 
 /** @module
  *
@@ -133,13 +133,9 @@ int getevent(char *restriction, char *cont, tupleinfo *tuple)
         return 0;
 }
 
-void updater(int src, int dst, table *tab)
+int updater(int src, int dst, int typeid, int resid)
 {
-        int src_time;
-
-        src_time=tab->chr[time].gen[src];
-
-        tab->chr[time].gen[dst]=src_time;
+	return(resid);
 }
 
 int module_precalc(moduleoption *opt)
@@ -147,11 +143,11 @@ int module_precalc(moduleoption *opt)
         int c;
 
         for(c=0;c<numsa;c++) {
-                if(updater_check(sa[c].tupleid2)) {
+                if(updater_check(sa[c].tupleid2, time)) {
                         error(_("Event '%s' already depends on another "
                         	"event"), dat_tuplemap[sa[c].tupleid2].name);
                 }
-                updater_new(sa[c].tupleid1, sa[c].tupleid2, updater);
+                updater_new(sa[c].tupleid1, sa[c].tupleid2, time, updater);
         }
         return(0);
 }
