@@ -15,7 +15,7 @@
 /* along with this program; if not, write to the Free Software             */
 /* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA */
 
-/* $Id: data.c,v 1.21 2006-02-04 14:16:12 avian Exp $ */
+/* $Id: data.c,v 1.22 2006-02-20 18:22:02 avian Exp $ */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -210,8 +210,9 @@ int domain_compare(domain *d1, domain *d2)
 	assert(d2!=NULL);
 	assert(d1->val!=NULL);
 	assert(d2->val!=NULL);
-	assert(d1->valnum>0);
-	assert(d2->valnum>0);
+	assert(d1->valnum>=0);
+	assert(d2->valnum>=0);
+
 
 	if(d1->restype!=d2->restype) return(0);
 	if(d1->valnum!=d2->valnum) return(0);
@@ -272,7 +273,7 @@ int compact_domains()
 		debug("compact_domains: %d tuples in %d", cur->tuplenum, num);
 
 		if(cur->valnum<1) {
-			error(_("Domain '%d' for resource type '%d' is empty"),
+			error(_("Domain '%d' for resource type '%s' is empty"),
 						num, cur->restype->type);
 			for(n=0;n<cur->tuplenum;n++) {
 				tupleid=cur->tuples[n];
