@@ -15,7 +15,7 @@
 /* along with this program; if not, write to the Free Software             */
 /* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA */
 
-/* $Id: xmlsup.c,v 1.32 2006-02-03 16:33:00 avian Exp $ */
+/* $Id: xmlsup.c,v 1.34 2006-03-22 20:25:39 avian Exp $ */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -349,13 +349,17 @@ static void parser_modules(xmlNodePtr cur)
  *
  * @param cur Pointer to the \<event\> node.
  * @param tupleid Tuple ID for this event.
- * @param repeats Number of repeats of this event. */
-static void parser_event_restrictions(xmlNodePtr cur, int tupleid, int repeats)
+ * @param repeats Number of repeats of this event. 
+ * @return 1 if there were unknown restrictions or 0 otherwise. */
+static int parser_event_restrictions(xmlNodePtr cur, int tupleid, int repeats)
 {
 	int n;
 	int result;
 	xmlChar *restriction;
 	xmlChar *content;
+	int unknown;
+
+	unknown=0;
 
         while(cur!=NULL) {
                 if(!xmlStrcmp(cur->name, XMLCHAR "restriction")) {
@@ -370,8 +374,9 @@ static void parser_event_restrictions(xmlNodePtr cur, int tupleid, int repeats)
 					FAIL("Restriction handler failed", cur);
 				} else if(result==2) {
 					info(_("Unknown event restriction '%s'"
-						"(line %d)"), restriction, 
+						" (line %d)"), restriction, 
 						xmlGetLineNo(cur));
+					unknown=1;
 				}
 			}
 
@@ -380,6 +385,8 @@ static void parser_event_restrictions(xmlNodePtr cur, int tupleid, int repeats)
                 }
                 cur=cur->next;
         }
+
+	return(unknown);
 }
 
 /** @brief Parse all event restrictions.
@@ -389,18 +396,27 @@ static void parser_events_restrictions(xmlNodePtr cur)
 {
 	int repeats;
 	int tupleid;
+	int unknown;
+
+	unknown=0;
 
 	while(cur!=NULL) {
 		if(!xmlStrcmp(cur->name, XMLCHAR "event")) {
 			tupleid=parser_getprop_int(cur, XMLCHAR "tupleid");
 			repeats=parser_getprop_int(cur, XMLCHAR "repeats");
 	
-			parser_event_restrictions(cur->children, 
-							tupleid, repeats);
+			if(parser_event_restrictions(cur->children, 
+							tupleid, repeats)) {
+				unknown=1;
+			}
 		}
 		cur=cur->next;
 	}
 
+	if(unknown&&verbosity<103) {
+		error(_("Unknown event restrictions found. "
+			"Increase verbosity level for more information."));
+	}
 }
 
 /** @brief Parse a single event.
@@ -482,11 +498,15 @@ static void parser_events(xmlNodePtr cur)
 /** @brief Parse restrictions for a single resource and call proper handlers.
  *
  * @param cur Pointer to the \<resource\> node.
- * @param res Pointer to the resource struct for this resource. */
-static void parser_resource_restrictions_one(xmlNodePtr cur, resource *res) 
+ * @param res Pointer to the resource struct for this resource. 
+ * @return 1 if there were unknown restrictions or 0 otherwise. */
+static int parser_resource_restrictions_one(xmlNodePtr cur, resource *res) 
 {
 	xmlChar *restriction, *content;
 	int result;
+	int unknown;
+
+	unknown=0;
 	
 	while (cur!=NULL) {
 		if(!xmlStrcmp(cur->name, XMLCHAR "restriction")) {
@@ -497,15 +517,20 @@ static void parser_resource_restrictions_one(xmlNodePtr cur, resource *res)
 								CHAR content);
 
 			if(result==1) FAIL("Restriction handler failed", cur);
-			if(result==2) info(_("Unknown resource restriction '%s'"
-						"(line %d)"), restriction, 
+			if(result==2) {
+				info(_("Unknown resource restriction '%s'"
+						" (line %d)"), restriction, 
 						xmlGetLineNo(cur));
+				unknown=1;
+			}
 
 			xmlFree(restriction);
 			xmlFree(content);
 		}
 		cur=cur->next;
 	}
+
+	return unknown;
 }
 
 /** @brief Parse all resource restrictions for a single resource type.
@@ -518,13 +543,18 @@ static void parser_resource_restrictions(xmlNodePtr cur, resourcetype *restype)
 	int n;
 	int resid;
 	int resid1, resid2;
+	int unknown;
+
+	unknown=0;
 
 	while(cur!=NULL) {
 		if(!xmlStrcmp(cur->name, XMLCHAR "resource")) {
                         resid=parser_getprop_int(cur, XMLCHAR "resid");
 
 			res=&restype->res[resid];
-			parser_resource_restrictions_one(cur->children, res);
+			if(parser_resource_restrictions_one(cur->children,res)){
+				unknown=1;
+			}
                 } else if((!xmlStrcmp(cur->name, XMLCHAR "linear"))||
 				(!xmlStrcmp(cur->name, XMLCHAR "matrix"))) {
 
@@ -533,12 +563,19 @@ static void parser_resource_restrictions(xmlNodePtr cur, resourcetype *restype)
 
 			for(n=resid1;n<=resid2;n++) {
 				res=&restype->res[n];
-				parser_resource_restrictions_one(cur->children,
-									res);
+				if(parser_resource_restrictions_one(
+							cur->children, res)) {
+					unknown=1;
+				}
 			}
 		}
 		cur=cur->next;
 	}
+
+	if(unknown&&verbosity<103) {
+		error(_("Unknown resource restrictions found. "
+			"Increase verbosity level for more information."));
+	}
 }
 
 /** @brief Parse all resource restrictions.
